@@ -37,6 +37,12 @@ from ..version import __version__
     hidden=True,
     envvar="SYM_LOG_DIR",
 )
+@click.option(
+    "--session-length",
+    type=click.INT,
+    help="The length of the session requested from STS.",
+    envvar="SYM_SESSION_LENGTH",
+)
 @click.make_pass_decorator(GlobalOptions, ensure=True)
 @resource_option
 @setup_segment(write_key=SegmentWriteKey)
@@ -48,6 +54,7 @@ def sym(
     resource: str,
     aws_region: str,
     log_dir: Optional[str],
+    session_length: Optional[int],
 ) -> None:
     """
     Access resources managed by Sym Flows.
@@ -59,5 +66,6 @@ def sym(
     options.debug = debug
     options.log_dir = log_dir
     options.aws_region = aws_region
+    options.session_length = session_length
 
-    SymUpdater().auto_update()
+    SymUpdater(debug=debug).auto_update()
