@@ -36,11 +36,11 @@ LaunchDarklyParams: OrgParams = {
     ),
     "aws_okta_params": {
         "mfa_provider": "OKTA",
-        "mfa_factor_type": "push",
+        "mfa_factor_type": "auto",
         "assume_role_ttl": "1h",
         "session_ttl": "30m",
     },
-    "saml2aws_params": {"mfa": "PUSH", "aws_session_duration": "1800"},
+    "saml2aws_params": {"mfa": "Auto", "aws_session_duration": "1800"},
     "profiles": {
         "production": Profile(
             display_name="Production",
@@ -148,11 +148,11 @@ PARAMS: Dict[str, OrgParams] = {
         ),
         "aws_okta_params": {
             "mfa_provider": "OKTA",
-            "mfa_factor_type": "push",
+            "mfa_factor_type": "auto",
             "assume_role_ttl": "1h",
             "session_ttl": "30m",
         },
-        "saml2aws_params": {"mfa": "PUSH", "aws_session_duration": "1800"},
+        "saml2aws_params": {"mfa": "Auto", "aws_session_duration": "1800"},
         "profiles": {
             "test": Profile(
                 display_name="Test",
@@ -183,11 +183,11 @@ PARAMS: Dict[str, OrgParams] = {
         ),
         "aws_okta_params": {
             "mfa_provider": "OKTA",
-            "mfa_factor_type": "push",
+            "mfa_factor_type": "auto",
             "assume_role_ttl": "1h",
             "session_ttl": "30m",
         },
-        "saml2aws_params": {"mfa": "PUSH", "aws_session_duration": "1800"},
+        "saml2aws_params": {"mfa": "Auto", "aws_session_duration": "1800"},
         "profiles": {
             "prod": Profile(
                 display_name="Prod",
