@@ -144,6 +144,7 @@ class SymUpdater:
             return subprocess.run(
                 command,
                 timeout=INSTALL_TIMEOUT,
+                text=True,
                 **kwargs,
             )
         except TimeoutExpired as e:
@@ -217,6 +218,11 @@ class SymUpdater:
         if not self.url:
             return False
 
+        self._log(
+            f"Upgrading in-place. You can also manually follow the steps at https://docs.symops.com/docs/install-{self.cli}#manual-install.",
+            fg="bright_black",
+        )
+
         try:
             filename, _ = urlretrieve(self.url["url"])
         except URLError:
@@ -232,6 +238,12 @@ class SymUpdater:
                     member.name = str(Path(member.name).relative_to(prefix))
                     tar.extract(member, path=self.dir)
             return True
+        except PermissionError:
+            self._log(
+                f"Permission error. Try running `sudo {Config.get_dir_name()} update`.",
+                fg="red",
+            )
+            return False
         except tarfile.TarError:
             return False
 
@@ -245,7 +257,7 @@ class SymUpdater:
         return self.update_other()
 
     def update(self, replace=False):
-        self._log("Quickly checking for Sym CLI updates...", fg="white", nl=False)
+        self._log("Quickly checking for updates...", fg="white", nl=False)
         if not self.needs_update():
             self._log("no updates found, carry on!", fg="white")
             return
