@@ -7,6 +7,9 @@ from unittest.mock import MagicMock
 import pytest
 from semver import VersionInfo
 
+from sym.cli.helpers.config import SymConfigFile
+from sym.cli.helpers.updater import FAIL_LOG_PATH
+
 V1 = VersionInfo.parse("0.0.1")
 
 
@@ -130,6 +133,25 @@ def test_update_brew_failed_debug(brew_updater, capture_command, capsys):
         assert "an error!" in capsys.readouterr().err
 
 
+def test_update_brew_timeout(brew_updater, capture_command, capsys):
+    capture_command.register_output(r"brew --repo", "/foo/bar")
+    capture_command.register_output(r"brew upgrade", "something slow...", timeout=True)
+    with capture_command():
+        brew_updater.debug = True
+        assert brew_updater._update() == False
+
+    capture_command.assert_command(
+        ["brew", "--repo", "symopsio/tap"],
+        ["git", "pull", "origin", "master"],
+        ["brew", "upgrade", "sym"],
+        ["brew", "link", "sym"],
+    )
+
+    config_file = SymConfigFile(file_name=FAIL_LOG_PATH, uid_scope=False)
+    assert str(config_file.path) in capsys.readouterr().err
+    assert "something slow..." in config_file.read()
+
+
 @pytest.mark.skipif(not os.getenv("CI"), reason="skipping real requests locally")
 def test_update_other(other_updater):
     version = other_updater.get_latest_version()
