@@ -6,6 +6,7 @@ from expects import *
 from sym.cli.helpers.config import SymConfigFile
 from sym.cli.saml_clients.saml2aws import Saml2Aws
 from sym.cli.tests.helpers.capture import CaptureCommand
+from sym.cli.tests.helpers.sandbox import Sandbox
 from sym.cli.tests.saml_clients.conftest import TestContextFixture
 
 pytestmark = [
@@ -27,6 +28,22 @@ def test_saml2aws(
     )
 
 
+def test_saml2aws_is_setup(
+    test_context: TestContextFixture[Saml2Aws],
+    capture_command: CaptureCommand,
+    sandbox: Sandbox,
+    config_with_duplicate_sections: str,
+) -> None:
+    with sandbox.push_home():
+        sandbox.create_file("home/.saml2aws", contents=config_with_duplicate_sections)
+        with test_context(debug=False) as saml2aws:
+            with capture_command():
+                capture_command.register_output(
+                    "saml2aws --version", "2.26.2", stderr=True
+                )
+                assert saml2aws.is_setup() is True
+
+
 def test_saml2aws_get_creds(
     test_context: TestContextFixture[Saml2Aws],
     capture_command: CaptureCommand,
@@ -36,6 +53,14 @@ def test_saml2aws_get_creds(
             expect(saml2aws.get_creds()).to(have_keys({"AWS_REGION": "foobar"}))
 
 
+def test_saml2aws_session_length(test_context: TestContextFixture[Saml2Aws]):
+    with test_context(debug=False) as saml2aws:
+        saml2aws.options.session_length = 60
+        expect(
+            dict(saml2aws.ensure_config()[saml2aws._section_name]),
+        ).to(have_key("aws_session_duration", "3600"))
+
+
 def test_saml2aws_debug(
     test_context: TestContextFixture[Saml2Aws], capture_command: CaptureCommand
 ) -> None:
