@@ -1,7 +1,6 @@
 from unittest.mock import patch
 
 import pytest
-from click import BadParameter
 
 from sym.cli.errors import InvalidResource, UnknownError
 from sym.cli.helpers.contexts import push_env
@@ -78,8 +77,10 @@ def test_env_vars_override_invalid(click_setup):
             assert "Invalid resource name 'invalid'" in result.output
 
 
+@patch("sym.cli.helpers.updater.SymUpdater.is_local")
 @patch("click.Group.invoke")
-def test_unknown_error(invoke_mock, click_setup):
+def test_unknown_error(invoke_mock, is_local_mock, click_setup):
+    is_local_mock.return_value = False
     invoke_mock.side_effect = RuntimeError("foo")
 
     with click_setup(set_org=False, set_client=False) as runner:
@@ -88,8 +89,10 @@ def test_unknown_error(invoke_mock, click_setup):
         assert "foo" in result.output
 
 
+@patch("sym.cli.helpers.updater.SymUpdater.is_local")
 @patch("click.Group.invoke")
-def test_unknown_error_debug(invoke_mock, click_setup):
+def test_unknown_error_debug(invoke_mock, is_local_mock, click_setup):
+    is_local_mock.return_value = False
     invoke_mock.side_effect = RuntimeError("foo")
 
     with click_setup(set_org=False, set_client=False) as runner:
